@@ -13,17 +13,22 @@ eval "use JavaScript::Minifier";
 our $NO_MINIFY = $@;
 
 sub layout {
-    my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    my ($self,$data,$args);
+    $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
+
     my @args = (
-        encodes => '',
-        matrix  => 1,
+        @_,
         table   => {
+            %{ $args->{table} || {} },
             role => 'presentation',
             ( map {$_ => 0} qw( border cellspacing cellpadding ) ),
         },
+        encodes => '',
+        matrix  => 1,
         _layout => 1,
-        @_,
     );
+
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
 }
 
@@ -32,13 +37,18 @@ sub checkerboard {
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
     ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
 
-    my $colors = $args->{colors} ? $args->{colors} : [qw(red white)];
+    my $colors = $args->{colors} ? $args->{colors} : [qw(red green)];
+    $colors = [ $colors ] unless ref $colors;
+    $args->{extra} ||= 'white';
+    push @$colors, $args->{extra} unless $args->{_max_cols} % @$colors;
+
     my @args = (
-        td       => { style  => { 'background-color' => $colors } },
         matrix   => 1,
         headings => sub { join(' ', map { sprintf '<b>%s</b>', ucfirst(lc($_)) } split ('_', shift || '')) },
         @_,
+        td => { %{ $args->{td} || {} }, style  => { 'background-color' => $colors } },
     );
+
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
 }
 
@@ -59,25 +69,29 @@ sub calculator {
         height => 65,
         width  => 65,
         align  => 'center',
+        %{ $args->{td} || {} },
         style  => { 
             'font-size' => 'xx-large',
             padding => 0,
             margins => 0,
+            %{ $args->{td}{style} || {} },
         },
     );
 
     my $attrs = 'font-size: xx-large; font-weight: bold; font-family: monospace;';
 
     my @args = (
+        @_,
         table => {
             width => '20%',
+            %{ $args->{table} || {} },
             style => {
                 border  => 'thick outset',
                 padding => 0,
                 margins => 0,
+                %{ $args->{table}{style} || {} },
             },
         },
-        @_,
         caption     => qq(<input id="display" style="background-color: #F1FACA; height: 8%; width: 80%; text-align: right; $attrs" />),
         td          => [ { %attrs }, sub { qq(<button style="width: 100%; height: 100%; $attrs">$_[0]</button>) } ],
         -row3col3   => { rowspan => 2, %attrs },
@@ -105,14 +119,15 @@ sub conway {
     $args->{on}    ||= '#00BFA5';
     $args->{off}   ||= '#EEEEEE';
     $args->{colors} = ($NO_SPECTRUM or !$args->{fade})
-        ? [ $args->{off}, ($args->{on}) x 9 ]
-        : [ $args->{off}, (reverse Color::Spectrum::generate( 16, $args->{off}, $args->{on} ))[0..9] ];
+        ? [ ($args->{on}) x 10 ]
+        : [ Color::Spectrum::generate( 10, $args->{on}, $args->{off} ) ];
 
     my @cells;
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
         for my $c ( 0 .. $args->{_max_cols} - 1 ) {
+            my $cell = sprintf '-row%scol%s', $r, $c;
             push @cells,
-                sprintf( "-row%scol%s", $r, $c ) => {
+                $cell => {
                     id     => join( '-', $r, $c ),
                     class  => 'conway',
                     width  => '30px',
@@ -123,12 +138,8 @@ sub conway {
     }
 
     my @args = (
-        pinhead  => 0,
-        tgroups  => 0,
-        headless => 0,
-        matrix   => 1,
-        caption  => { '<button onClick="start()">Step</button>' => { align => 'bottom' } },
         @cells,
+        caption  => { '<button onClick="start()">Step</button>' => { align => 'bottom' } },
         @_,
     );
 
@@ -419,12 +430,13 @@ constructing your own custom Spreadsheet::HTML generators.
       # pull out custom named parameters from $params
       my $color = $params->{color};
 
-      my @args = (
-          # add custom args here
+      my @params = (
+          # add custom params that client CAN overide here
           @_,
+          # add custom params that client can NOT overide here
       );
 
-      $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+      $self ? $self->generate( @params ) : Spreadsheet::HTML::generate( @params );
   }
 
 It is not pretty, but it keeps the named parameters in line even
@@ -433,19 +445,20 @@ if stray, bare array references are used by the client:
   $table->my_generator( [ 'data here' ], color => 'red' );
 
 A simpler, less flexible form is available if you do not need to
-pull out custom args:
+pull out client params:
 
   use Spreadsheet::HTML;
 
   sub my_generator {
       my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
 
-      my @args = (
-          # add custom args here
+      my @params = (
+          # add custom params that client CAN overide here
           @_,
+          # add custom params that client can NOT overide here
       );
 
-      $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+      $self ? $self->generate( @params ) : Spreadsheet::HTML::generate( @params );
   }
 
 Plans are in the works to simplify this "API," possibly even
@@ -460,14 +473,18 @@ to provide a real plugin interface.
 Layout tables are not recommended, but if you choose to
 use them you should label them as such. This adds W3C
 recommended layout attributes to the table tag and features:
-emiting only <td> tags, no padding or pruning of rows, forces
+emit only <td> tags, no padding or pruning of rows, forces
 no HTML entity encoding in table cells.
 
 =item * C<checkerboard( colors, %params )>
 
 Preset for tables with checkerboard colors.
 
-  checkerboard( colors => [qw(red green orange)] )
+  checkerboard( colors => [qw(yellow orange)], extra => 'blue' )
+
+Attempts to form diagonal patterns by adding an extra color
+if need be. C<colors> default to red and green and C<extra>
+defaults to white.
 
 =item * C<conway( on, off, fade, jquery, %params )>
 
@@ -475,6 +492,16 @@ Game of life. From an implementation i wrote back in college.
 
   conway( on => 'red', off => 'gray' )
 
+If you have L<Color::Spectrum> installed (and optionally
+L<Color::Library>) then you can turn fade on for more
+effects:
+
+  # without Color::Library
+  conway( on => '#FF0000', off => '#999999', fade => 1 )
+
+  # with Color::Library
+  conway( on => 'red', off => 'gray', fade => 1 )
+
 Uses Google's jQuery API unless you specify another URI via
 the C<jquery> param. Javascript will be minified
 via L<Javascript::Minifier> if it is installed.
